==> linstor-server-1.18.1-rc.1.tar.gz: linstor-server-1.18.1-rc.1/server/src/main/java/com/linbit/linstor/api/pojo/AutoSelectFilterPojo.java <==
package com.linbit.linstor.api.pojo;

import com.linbit.linstor.api.interfaces.AutoSelectFilterApi;
import com.linbit.linstor.storage.kinds.DeviceLayerKind;
import com.linbit.linstor.storage.kinds.DeviceProviderKind;
import com.linbit.linstor.storage.kinds.ExtTools;
import com.linbit.linstor.storage.kinds.ExtToolsInfo;
import com.linbit.linstor.storage.kinds.ExtToolsInfo.Version;

import javax.annotation.Nullable;

import java.util.List;
import java.util.Map;

public class AutoSelectFilterPojo implements AutoSelectFilterApi
{
    private @Nullable Integer placeCount; // null only allowed for resource groups
    private @Nullable Integer additionalPlaceCount;
    private @Nullable List<String> nodeNameList;
    private @Nullable List<String> storPoolNameList;
    private @Nullable List<String> storPoolDisklessNameList;
    private @Nullable List<String> doNotPlaceWithRscList;
    private @Nullable String doNotPlaceWithRegex;
    private @Nullable List<String> replicasOnSameList;
    private @Nullable List<String> replicasOnDifferentList;
    private @Nullable List<DeviceLayerKind> layerStackList;
    private @Nullable List<DeviceProviderKind> providerList;
    private @Nullable Boolean disklessOnRemaining;
    private @Nullable List<String> skipAlreadyPlacedOnNodeNamesCheck;
    private @Nullable Boolean skipAlreadyPlacedOnAllNodeCheck;
    private @Nullable String disklessType;
    private @Nullable Map<ExtTools, Version> requiredExtTools;

    public AutoSelectFilterPojo(
        @Nullable Integer placeCountRef,
        @Nullable Integer additionalPlaceCountRef,
        @Nullable List<String> nodeNameListRef,
        @Nullable List<String> storPoolNameListRef,
        @Nullable List<String> storPoolDisklessNameListRef,
        @Nullable List<String> doNotPlaceWithRscListRef,
        @Nullable String doNotPlaceWithRegexRef,
        @Nullable List<String> replicasOnSameListRef,
        @Nullable List<String> replicasOnDifferentListRef,
        @Nullable List<DeviceLayerKind> layerStackListRef,
        @Nullable List<DeviceProviderKind> deviceProviderKindsRef,
        @Nullable Boolean disklessOnRemainingRef,
        @Nullable List<String> skipAlreadyPlacedOnNodeNamesCheckRef,
        @Nullable Boolean skipAlreadyPlacedOnAllNodeCheckRef,
        @Nullable String disklessTypeRef,
        @Nullable Map<ExtTools, Version> requiredExtToolsRef
    )
    {
        placeCount = placeCountRef;
        additionalPlaceCount = additionalPlaceCountRef;
        nodeNameList = nodeNameListRef;
        storPoolNameList = storPoolNameListRef;
        storPoolDisklessNameList = storPoolDisklessNameListRef;
        doNotPlaceWithRscList = doNotPlaceWithRscListRef;
        doNotPlaceWithRegex = doNotPlaceWithRegexRef;
        replicasOnSameList = replicasOnSameListRef;
        replicasOnDifferentList = replicasOnDifferentListRef;
        disklessOnRemaining = disklessOnRemainingRef;
        layerStackList = layerStackListRef;
        providerList = deviceProviderKindsRef;
        skipAlreadyPlacedOnNodeNamesCheck = skipAlreadyPlacedOnNodeNamesCheckRef;
        skipAlreadyPlacedOnAllNodeCheck = skipAlreadyPlacedOnAllNodeCheckRef;
        disklessType = disklessTypeRef;
        requiredExtTools = requiredExtToolsRef;
    }

    public static AutoSelectFilterPojo copy(AutoSelectFilterApi api) {
        return new AutoSelectFilterPojo(
            api.getReplicaCount(),
            api.getAdditionalReplicaCount(),
            api.getNodeNameList(),
            api.getStorPoolNameList(),
            api.getStorPoolDisklessNameList(),
            api.getDoNotPlaceWithRscList(),
            api.getDoNotPlaceWithRscRegex(),
            api.getReplicasOnSameList(),
            api.getReplicasOnDifferentList(),
            api.getLayerStackList(),
            api.getProviderList(),
            api.getDisklessOnRemaining(),
            api.skipAlreadyPlacedOnNodeNamesCheck(),
            api.skipAlreadyPlacedOnAllNodeCheck(),
            api.getDisklessType(),
            api.getRequiredExtTools()
        );
    }

    public static AutoSelectFilterPojo merge(
        AutoSelectFilterApi... cfgArr
    )
    {
        Integer placeCount = null;
        Integer additionalPlaceCount = null;
        List<String> replicasOnDifferentList = null;
        List<String> replicasOnSameList = null;
        String notPlaceWithRscRegex = null;
        List<String> notPlaceWithRscList = null;
        List<String> nodeNameList = null;
        List<String> storPoolNameList = null;
        List<String> storPoolDisklessNameList = null;
        List<DeviceLayerKind> layerStack = null;
        List<DeviceProviderKind> providerList = null;
        Boolean disklessOnRemaining = null;
        List<String> skipAlreadyPlacedOnNodeCheck = null;
        Boolean skipAlreadyPlacedOnAllNodeCheck = null;
        String disklessType = null;
        Map<ExtTools, ExtToolsInfo.Version> requiredExtTools = null;

        for (AutoSelectFilterApi cfgApi : cfgArr)
        {
            if (cfgApi != null)
            {
                if (placeCount == null)
                {
                    placeCount = cfgApi.getReplicaCount();
                }
                if (additionalPlaceCount == null)
                {
                    additionalPlaceCount = cfgApi.getAdditionalReplicaCount();
                }
                if (replicasOnDifferentList == null)
                {
                    replicasOnDifferentList = cfgApi.getReplicasOnDifferentList();
                }
                if (replicasOnSameList == null)
                {
                    replicasOnSameList = cfgApi.getReplicasOnSameList();
                }
                if (notPlaceWithRscList == null)
                {
                    notPlaceWithRscList = cfgApi.getDoNotPlaceWithRscList();
                }
                if (notPlaceWithRscRegex == null)
                {
                    notPlaceWithRscRegex = cfgApi.getDoNotPlaceWithRscRegex();
                }
                if (storPoolNameList == null)
                {
                    storPoolNameList = cfgApi.getStorPoolNameList();
                }
                if (storPoolDisklessNameList == null)
                {
                    storPoolDisklessNameList = cfgApi.getStorPoolDisklessNameList();
                }
                if (nodeNameList == null)
                {
                    nodeNameList = cfgApi.getNodeNameList();
                }
                if (layerStack == null)
                {
                    layerStack = cfgApi.getLayerStackList();
                }
                if (providerList == null)
                {
                    providerList = cfgApi.getProviderList();
                }
                if (disklessOnRemaining == null)
                {
                    disklessOnRemaining = cfgApi.getDisklessOnRemaining();
                }
                if (skipAlreadyPlacedOnNodeCheck == null)
                {
                    skipAlreadyPlacedOnNodeCheck = cfgApi.skipAlreadyPlacedOnNodeNamesCheck();
                }
                if (skipAlreadyPlacedOnAllNodeCheck == null)
                {
                    skipAlreadyPlacedOnAllNodeCheck = cfgApi.skipAlreadyPlacedOnAllNodeCheck();
                }
                if (disklessType == null)
                {
                    disklessType = cfgApi.getDisklessType();
                }
                if (requiredExtTools == null)
                {
                    requiredExtTools = cfgApi.getRequiredExtTools();
                }
            }
        }

        return new AutoSelectFilterPojo(
            placeCount,
            additionalPlaceCount,
            nodeNameList,
            storPoolNameList,
            storPoolDisklessNameList,
            notPlaceWithRscList,
            notPlaceWithRscRegex,
            replicasOnSameList,
            replicasOnDifferentList,
            layerStack,
            providerList,
            disklessOnRemaining,
            skipAlreadyPlacedOnNodeCheck,
            skipAlreadyPlacedOnAllNodeCheck,
            disklessType,
            requiredExtTools
        );
    }

    @Override
    public @Nullable Integer getReplicaCount()
    {
        return placeCount;
    }

    @Override
    public @Nullable Integer getAdditionalReplicaCount()
    {
        return additionalPlaceCount;
    }

    @Override
    public @Nullable List<String> getNodeNameList()
    {
        return nodeNameList;
    }

    @Override
    public @Nullable List<String> getStorPoolNameList()
    {
        return storPoolNameList;
    }

    @Override
    public List<String> getStorPoolDisklessNameList()
    {
        return storPoolDisklessNameList;
    }

    @Override
    public @Nullable List<String> getDoNotPlaceWithRscList()
    {
        return doNotPlaceWithRscList;
    }

    @Override
    public @Nullable String getDoNotPlaceWithRscRegex()
    {
        return doNotPlaceWithRegex;
    }

    @Override
    public @Nullable List<String> getReplicasOnSameList()
    {
        return replicasOnSameList;
    }

    @Override
    public @Nullable List<String> getReplicasOnDifferentList()
    {
        return replicasOnDifferentList;
    }

    @Override
    public @Nullable List<DeviceLayerKind> getLayerStackList()
    {
        return layerStackList;
    }

    @Override
    public @Nullable List<DeviceProviderKind> getProviderList()
    {
        return providerList;
    }

    @Override
    public @Nullable Boolean getDisklessOnRemaining()
    {
        return disklessOnRemaining;
    }

    @Override
    public @Nullable List<String> skipAlreadyPlacedOnNodeNamesCheck()
    {
        return skipAlreadyPlacedOnNodeNamesCheck;
    }

    @Override
    public Boolean skipAlreadyPlacedOnAllNodeCheck()
    {
        return skipAlreadyPlacedOnAllNodeCheck;
    }

    @Override
    public @Nullable String getDisklessType()
    {
        return disklessType;
    }

    @Override
    public @Nullable Map<ExtTools, Version> getRequiredExtTools()
    {
        return requiredExtTools;
    }

    public void setPlaceCount(@Nullable Integer placeCountRef)
    {
        placeCount = placeCountRef;
    }

    public void setAdditionalPlaceCount(@Nullable Integer additionalPlaceCountRef)
    {
        additionalPlaceCount = additionalPlaceCountRef;
    }

    public void setNodeNameList(@Nullable List<String> nodeNameListRef)
    {
        nodeNameList = nodeNameListRef;
    }

    public void setStorPoolNameList(@Nullable List<String> storPoolNameListRef)
    {
        storPoolNameList = storPoolNameListRef;
    }

    public void setDoNotPlaceWithRscList(@Nullable List<String> doNotPlaceWithRscListRef)
    {
        doNotPlaceWithRscList = doNotPlaceWithRscListRef;
    }

    public void setDoNotPlaceWithRegex(@Nullable String doNotPlaceWithRegexRef)
    {
        doNotPlaceWithRegex = doNotPlaceWithRegexRef;
    }

    public void setReplicasOnSameList(@Nullable List<String> replicasOnSameListRef)
    {
        replicasOnSameList = replicasOnSameListRef;
    }

    public void setReplicasOnDifferentList(@Nullable List<String> replicasOnDifferentListRef)
    {
        replicasOnDifferentList = replicasOnDifferentListRef;
    }

    public void setLayerStackList(@Nullable List<DeviceLayerKind> layerStackListRef)
    {
        layerStackList = layerStackListRef;
    }

    public void setProviderList(@Nullable List<DeviceProviderKind> providerListRef)
    {
        providerList = providerListRef;
    }

    public void setDisklessOnRemaining(@Nullable Boolean disklessOnRemainingRef)
    {
        disklessOnRemaining = disklessOnRemainingRef;
    }

    public void setSkipAlreadyPlacedOnNodeNamesCheck(@Nullable List<String> skipAlreadyPlacedOnNodeNamesCheckRef)
    {
        skipAlreadyPlacedOnNodeNamesCheck = skipAlreadyPlacedOnNodeNamesCheckRef;
    }

    public void setDisklessType(@Nullable String disklessTypeRef)
    {
        disklessType = disklessTypeRef;
    }
}

==> linstor-server-1.20.2.tar.gz: linstor-server-1.20.2/server/src/main/java/com/linbit/linstor/api/pojo/AutoSelectFilterPojo.java <==
package com.linbit.linstor.api.pojo;

import com.linbit.linstor.api.interfaces.AutoSelectFilterApi;
import com.linbit.linstor.storage.kinds.DeviceLayerKind;
import com.linbit.linstor.storage.kinds.DeviceProviderKind;
import com.linbit.linstor.storage.kinds.ExtTools;
import com.linbit.linstor.storage.kinds.ExtToolsInfo;
import com.linbit.linstor.storage.kinds.ExtToolsInfo.Version;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import java.util.List;
import java.util.Map;

public class AutoSelectFilterPojo implements AutoSelectFilterApi
{
    private @Nullable Integer placeCount; // null only allowed for resource groups
    private @Nullable Integer additionalPlaceCount;
    private @Nullable List<String> nodeNameList;
    private @Nullable List<String> storPoolNameList;
    private @Nullable List<String> storPoolDisklessNameList;
    private @Nullable List<String> doNotPlaceWithRscList;
    private @Nullable String doNotPlaceWithRegex;
    private @Nullable List<String> replicasOnSameList;
    private @Nullable List<String> replicasOnDifferentList;
    private @Nullable List<DeviceLayerKind> layerStackList;
    private @Nullable List<DeviceProviderKind> providerList;
    private @Nullable Boolean disklessOnRemaining;
    private @Nullable List<String> skipAlreadyPlacedOnNodeNamesCheck;
    private @Nullable Boolean skipAlreadyPlacedOnAllNodeCheck;
    private @Nullable String disklessType;
    private @Nullable Map<ExtTools, Version> requiredExtTools;

    public AutoSelectFilterPojo(
        @Nullable Integer placeCountRef,
        @Nullable Integer additionalPlaceCountRef,
        @Nullable List<String> nodeNameListRef,
        @Nullable List<String> storPoolNameListRef,
        @Nullable List<String> storPoolDisklessNameListRef,
        @Nullable List<String> doNotPlaceWithRscListRef,
        @Nullable String doNotPlaceWithRegexRef,
        @Nullable List<String> replicasOnSameListRef,
        @Nullable List<String> replicasOnDifferentListRef,
        @Nullable List<DeviceLayerKind> layerStackListRef,
        @Nullable List<DeviceProviderKind> deviceProviderKindsRef,
        @Nullable Boolean disklessOnRemainingRef,
        @Nullable List<String> skipAlreadyPlacedOnNodeNamesCheckRef,
        @Nullable Boolean skipAlreadyPlacedOnAllNodeCheckRef,
        @Nullable String disklessTypeRef,
        @Nullable Map<ExtTools, Version> requiredExtToolsRef
    )
    {
        placeCount = placeCountRef;
        additionalPlaceCount = additionalPlaceCountRef;
        nodeNameList = nodeNameListRef;
        storPoolNameList = storPoolNameListRef;
        storPoolDisklessNameList = storPoolDisklessNameListRef;
        doNotPlaceWithRscList = doNotPlaceWithRscListRef;
        doNotPlaceWithRegex = doNotPlaceWithRegexRef;
        replicasOnSameList = replicasOnSameListRef;
        replicasOnDifferentList = replicasOnDifferentListRef;
        disklessOnRemaining = disklessOnRemainingRef;
        layerStackList = layerStackListRef;
        providerList = deviceProviderKindsRef;
        skipAlreadyPlacedOnNodeNamesCheck = skipAlreadyPlacedOnNodeNamesCheckRef;
        skipAlreadyPlacedOnAllNodeCheck = skipAlreadyPlacedOnAllNodeCheckRef;
        disklessType = disklessTypeRef;
        requiredExtTools = requiredExtToolsRef;
    }

    public static AutoSelectFilterPojo copy(AutoSelectFilterApi api) {
        return new AutoSelectFilterPojo(
            api.getReplicaCount(),
            api.getAdditionalReplicaCount(),
            api.getNodeNameList(),
            api.getStorPoolNameList(),
            api.getStorPoolDisklessNameList(),
            api.getDoNotPlaceWithRscList(),
            api.getDoNotPlaceWithRscRegex(),
            api.getReplicasOnSameList(),
            api.getReplicasOnDifferentList(),
            api.getLayerStackList(),
            api.getProviderList(),
            api.getDisklessOnRemaining(),
            api.skipAlreadyPlacedOnNodeNamesCheck(),
            api.skipAlreadyPlacedOnAllNodeCheck(),
            api.getDisklessType(),
            api.getRequiredExtTools()
        );
    }

    public static @Nonnull AutoSelectFilterPojo merge(
        AutoSelectFilterApi... cfgArr
    )
    {
        Integer placeCount = null;
        Integer additionalPlaceCount = null;
        List<String> replicasOnDifferentList = null;
        List<String> replicasOnSameList = null;
        String notPlaceWithRscRegex = null;
        List<String> notPlaceWithRscList = null;
        List<String> nodeNameList = null;
        List<String> storPoolNameList = null;
        List<String> storPoolDisklessNameList = null;
        List<DeviceLayerKind> layerStack = null;
        List<DeviceProviderKind> providerList = null;
        Boolean disklessOnRemaining = null;
        List<String> skipAlreadyPlacedOnNodeCheck = null;
        Boolean skipAlreadyPlacedOnAllNodeCheck = null;
        String disklessType = null;
        Map<ExtTools, ExtToolsInfo.Version> requiredExtTools = null;

        for (AutoSelectFilterApi cfgApi : cfgArr)
        {
            if (cfgApi != null)
            {
                if (placeCount == null)
                {
                    placeCount = cfgApi.getReplicaCount();
                }
                if (additionalPlaceCount == null)
                {
                    additionalPlaceCount = cfgApi.getAdditionalReplicaCount();
                }
                if (replicasOnDifferentList == null)
                {
                    replicasOnDifferentList = cfgApi.getReplicasOnDifferentList();
                }
                if (replicasOnSameList == null)
                {
                    replicasOnSameList = cfgApi.getReplicasOnSameList();
                }
                if (notPlaceWithRscList == null)
                {
                    notPlaceWithRscList = cfgApi.getDoNotPlaceWithRscList();
                }
                if (notPlaceWithRscRegex == null)
                {
                    notPlaceWithRscRegex = cfgApi.getDoNotPlaceWithRscRegex();
                }
                if (storPoolNameList == null)
                {
                    storPoolNameList = cfgApi.getStorPoolNameList();
                }
                if (storPoolDisklessNameList == null)
                {
                    storPoolDisklessNameList = cfgApi.getStorPoolDisklessNameList();
                }
                if (nodeNameList == null)
                {
                    nodeNameList = cfgApi.getNodeNameList();
                }
                if (layerStack == null)
                {
                    layerStack = cfgApi.getLayerStackList();
                }
                if (providerList == null)
                {
                    providerList = cfgApi.getProviderList();
                }
                if (disklessOnRemaining == null)
                {
                    disklessOnRemaining = cfgApi.getDisklessOnRemaining();
                }
                if (skipAlreadyPlacedOnNodeCheck == null)
                {
                    skipAlreadyPlacedOnNodeCheck = cfgApi.skipAlreadyPlacedOnNodeNamesCheck();
                }
                if (skipAlreadyPlacedOnAllNodeCheck == null)
                {
                    skipAlreadyPlacedOnAllNodeCheck = cfgApi.skipAlreadyPlacedOnAllNodeCheck();
                }
                if (disklessType == null)
                {
                    disklessType = cfgApi.getDisklessType();
                }
                if (requiredExtTools == null)
                {
                    requiredExtTools = cfgApi.getRequiredExtTools();
                }
            }
        }

        return new AutoSelectFilterPojo(
            placeCount,
            additionalPlaceCount,
            nodeNameList,
            storPoolNameList,
            storPoolDisklessNameList,
            notPlaceWithRscList,
            notPlaceWithRscRegex,
            replicasOnSameList,
            replicasOnDifferentList,
            layerStack,
            providerList,
            disklessOnRemaining,
            skipAlreadyPlacedOnNodeCheck,
            skipAlreadyPlacedOnAllNodeCheck,
            disklessType,
            requiredExtTools
        );
    }

    @Override
    public @Nullable Integer getReplicaCount()
    {
        return placeCount;
    }

    @Override
    public @Nullable Integer getAdditionalReplicaCount()
    {
        return additionalPlaceCount;
    }

    @Override
    public @Nullable List<String> getNodeNameList()
    {
        return nodeNameList;
    }

    @Override
    public @Nullable List<String> getStorPoolNameList()
    {
        return storPoolNameList;
    }

    @Override
    public List<String> getStorPoolDisklessNameList()
    {
        return storPoolDisklessNameList;
    }

    @Override
    public @Nullable List<String> getDoNotPlaceWithRscList()
    {
        return doNotPlaceWithRscList;
    }

    @Override
    public @Nullable String getDoNotPlaceWithRscRegex()
    {
        return doNotPlaceWithRegex;
    }

    @Override
    public @Nullable List<String> getReplicasOnSameList()
    {
        return replicasOnSameList;
    }

    @Override
    public @Nullable List<String> getReplicasOnDifferentList()
    {
        return replicasOnDifferentList;
    }

    @Override
    public @Nullable List<DeviceLayerKind> getLayerStackList()
    {
        return layerStackList;
    }

    @Override
    public @Nullable List<DeviceProviderKind> getProviderList()
    {
        return providerList;
    }

    @Override
    public @Nullable Boolean getDisklessOnRemaining()
    {
        return disklessOnRemaining;
    }

    @Override
    public @Nullable List<String> skipAlreadyPlacedOnNodeNamesCheck()
    {
        return skipAlreadyPlacedOnNodeNamesCheck;
    }

    @Override
    public Boolean skipAlreadyPlacedOnAllNodeCheck()
    {
        return skipAlreadyPlacedOnAllNodeCheck;
    }

    @Override
    public @Nullable String getDisklessType()
    {
        return disklessType;
    }

    @Override
    public @Nullable Map<ExtTools, Version> getRequiredExtTools()
    {
        return requiredExtTools;
    }

    public void setPlaceCount(@Nullable Integer placeCountRef)
    {
        placeCount = placeCountRef;
    }

    public void setAdditionalPlaceCount(@Nullable Integer additionalPlaceCountRef)
    {
        additionalPlaceCount = additionalPlaceCountRef;
    }

    public void setNodeNameList(@Nullable List<String> nodeNameListRef)
    {
        nodeNameList = nodeNameListRef;
    }

    public void setStorPoolNameList(@Nullable List<String> storPoolNameListRef)
    {
        storPoolNameList = storPoolNameListRef;
    }

    public void setDoNotPlaceWithRscList(@Nullable List<String> doNotPlaceWithRscListRef)
    {
        doNotPlaceWithRscList = doNotPlaceWithRscListRef;
    }

    public void setDoNotPlaceWithRegex(@Nullable String doNotPlaceWithRegexRef)
    {
        doNotPlaceWithRegex = doNotPlaceWithRegexRef;
    }

    public void setReplicasOnSameList(@Nullable List<String> replicasOnSameListRef)
    {
        replicasOnSameList = replicasOnSameListRef;
    }

    public void setReplicasOnDifferentList(@Nullable List<String> replicasOnDifferentListRef)
    {
        replicasOnDifferentList = replicasOnDifferentListRef;
    }

    public void setLayerStackList(@Nullable List<DeviceLayerKind> layerStackListRef)
    {
        layerStackList = layerStackListRef;
    }

    public void setProviderList(@Nullable List<DeviceProviderKind> providerListRef)
    {
        providerList = providerListRef;
    }

    public void setDisklessOnRemaining(@Nullable Boolean disklessOnRemainingRef)
    {
        disklessOnRemaining = disklessOnRemainingRef;
    }

    public void setSkipAlreadyPlacedOnNodeNamesCheck(@Nullable List<String> skipAlreadyPlacedOnNodeNamesCheckRef)
    {
        skipAlreadyPlacedOnNodeNamesCheck = skipAlreadyPlacedOnNodeNamesCheckRef;
    }

    public void setDisklessType(@Nullable String disklessTypeRef)
    {
        disklessType = disklessTypeRef;
    }
}
